@@ -77,16 +77,19 @@ class Syncer:
         return result
 
     def _is_orphaned(self, generating_classes, entity, entity_ds, other_ds):
+        len_others = 0
+        len_unrefreshed = 0
         for generating_class in generating_classes:
             others = self.link_provider.others(
                 entity, entity_ds, generating_class, other_ds
             )
             if others:
+                len_others += len(others)
                 for other in others:
                     refreshed_other = other_ds.refresh(other)
                     if not refreshed_other:
-                        return True
-        return False
+                        len_unrefreshed += 1
+        return 0 < len_others == len_unrefreshed
 
     def _collect_orphaned_entities(self, entity_ds, entity_class, other_ds):
         generating_classes = self._collect_linked_classes(entity_class)
@@ -399,6 +402,7 @@ class Syncer:
         for orphaned_entity in self._collect_orphaned_entities(
             to_ds, to_class, from_ds
         ):
+            logging.info(f"❌ Trying to delete orphaned entity {orphaned_entity}")
             successful_deletion = to_ds.delete(orphaned_entity)
             if not successful_deletion:
                 operations.append(CouldNotDelete(orphaned_entity))
